from crocs.regex import Pattern, Any

e0 = Any('alpha', 'beta', 'gamma')
e0.test()
e0.hits()

